summaryrefslogtreecommitdiff
path: root/indra/newview/llviewertexteditor.cpp
diff options
context:
space:
mode:
authorOz Linden <oz@lindenlab.com>2017-05-23 04:56:13 -0400
committerOz Linden <oz@lindenlab.com>2017-05-23 04:56:13 -0400
commit069dd355f90116b500065b40bfb36622be1faee5 (patch)
treefe6cf12e89a715f46cf4e95ad91a5cf7f0e0c8a9 /indra/newview/llviewertexteditor.cpp
parentf9e049c9e5cc01b464e66cab3e34e33864946c0c (diff)
parent48af8529a80052e9bc42f81f36896739f8aff861 (diff)
merge changes for 5.0.5-release
Diffstat (limited to 'indra/newview/llviewertexteditor.cpp')
-rw-r--r--indra/newview/llviewertexteditor.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llviewertexteditor.cpp b/indra/newview/llviewertexteditor.cpp
index 9e09971ced..7d2d6e25c7 100644
--- a/indra/newview/llviewertexteditor.cpp
+++ b/indra/newview/llviewertexteditor.cpp
@@ -176,7 +176,7 @@ public:
mToolTip = inv_item->getName() + '\n' + inv_item->getDescription();
}
/*virtual*/ bool getDimensions(S32 first_char, S32 num_chars, S32& width, S32& height) const
{
if (num_chars == 0)
{
@@ -185,7 +185,7 @@ public:
}
else
{
- width = EMBEDDED_ITEM_LABEL_PADDING + mImage->getWidth() + mStyle->getFont()->getWidth(mLabel.c_str());
+ width = EMBEDDED_ITEM_LABEL_PADDING + mImage->getWidth() + mStyle->getFont()->getWidthF32(mLabel.c_str());
height = llmax(mImage->getHeight(), mStyle->getFont()->getLineHeight());
}
return false;
@@ -176,7 +176,7 @@ public:
mToolTip = inv_item->getName() + '\n' + inv_item->getDescription();
}
- /*virtual*/ bool getDimensions(S32 first_char, S32 num_chars, S32& width, S32& height) const
+ /*virtual*/ bool getDimensionsF32(S32 first_char, S32 num_chars, F32& width, S32& height) const
{
if (num_chars == 0)